@@ -209,8 +209,9 @@ SEXP call_daspk(SEXP y, SEXP yprime, SEXP times, SEXP resfunc, SEXP parms,
   lrw = LENGTH(rWork);
   rwork = (double *) R_alloc(lrw, sizeof(double));
     for (j = 0; j < lrw; j++) rwork[j] = REAL(rWork)[j];
-  timesteps = (double *) R_alloc(2, sizeof(double));
-     for (j=0; j<2; j++) timesteps[j] = 0.;
+    
+  //timesteps = (double *) R_alloc(2, sizeof(double));
+  for (j = 0; j < 2; j++) timesteps[j] = 0.;
 
   /**************************************************************************/
   /****** Initialization of globals, Parameters and Forcings (DLLs)    ******/
