@@ -264,8 +264,8 @@ SEXP call_radau(SEXP y, SEXP times, SEXP derivfunc, SEXP masfunc, SEXP jacfunc,
 
   /* initialise global R-variables...  */
   initglobals (nt, ntot);
-  timesteps = (double *) R_alloc(2, sizeof(double));
-     for (j=0; j<2; j++) timesteps[j] = 0.;
+  //timesteps = (double *) R_alloc(2, sizeof(double));
+  for (j=0; j<2; j++) timesteps[j] = 0.;
   
   /* Initialization of Parameters, Forcings (DLL) */
   initParms (initfunc, parms);
@@ -352,3 +352,4 @@ SEXP call_radau(SEXP y, SEXP times, SEXP derivfunc, SEXP masfunc, SEXP jacfunc,
   else
     return(YOUT2);
 }
+ 
