@@ -2,8 +2,7 @@
 /* Runge-Kutta Solvers, (C) Th. Petzoldt, License: GPL >=2                  */
 /* General RK Solver for methods with adaptive step size                    */
 /*==========================================================================*/
-/* Karline: call to rk_auto, setIstate: + number of rejected steps it_rej  
-   dense output Cash-Karp : R_TD, densetype=2 : dense output method 2...           */
+
 #include "rk_util.h"
 
 SEXP call_rkAuto(SEXP Xstart, SEXP Times, SEXP Func, SEXP Initfunc,
@@ -96,10 +95,9 @@ SEXP call_rkAuto(SEXP Xstart, SEXP Times, SEXP Func, SEXP Initfunc,
   xs  = NUMERIC_POINTER(Xstart);
   neq = length(Xstart);
   /*------------------------------------------------------------------------*/
-  /* timesteps (for compatibility with lsoda)                               */
+  /* timesteps (for advection computation in ReacTran)                      */
   /*------------------------------------------------------------------------*/
-  timesteps = (double *)R_alloc(2, sizeof(double)); 
-  for (i = 0; i < 2; i++) timesteps[i] = 1;
+  for (i = 0; i < 2; i++) timesteps[i] = 0;
 
   /*------------------------------------------------------------------------*/
   /* DLL, ipar, rpar (for compatibility with lsoda)                         */
@@ -166,11 +164,8 @@ SEXP call_rkAuto(SEXP Xstart, SEXP Times, SEXP Func, SEXP Initfunc,
 
   PROTECT(R_nknots = getListElement(Method, "nknots")); incr_N_Protect();
   if (length(R_nknots)) nknots = INTEGER(R_nknots)[0] + 1;
-
   if (nknots < 2) {nknots = 1; interpolate = FALSE;}
-  //if (dd || densetype > 0) interpolate = TRUE;
   if (densetype > 0) interpolate = TRUE;
-  
   yknots = (double*) R_alloc((neq + 1) * (nknots + 1), sizeof(double));
 
   /* matrix for holding states and global outputs */
@@ -273,7 +268,6 @@ SEXP call_rkAuto(SEXP Xstart, SEXP Times, SEXP Func, SEXP Initfunc,
     }
   }
 
-
   /*====================================================================*/
   /* call derivs again to get global outputs                            */
   /* j = -1 suppresses unnecessary internal copying                     */
@@ -288,21 +282,21 @@ SEXP call_rkAuto(SEXP Xstart, SEXP Times, SEXP Func, SEXP Initfunc,
       }
     }
   }
-  /* attach essential internal information (codes are compatible to lsoda) */
 
+  /* attach diagnostic information (codes are compatible to lsoda) */
   setIstate(R_yout, R_istate, istate, it_tot, stage, fsal, qerr, it_rej);
-
   if (densetype == 2)   istate[12] = it_tot * stage + 2; /* number of function evaluations */
-  
-  // experimental
-  // set default value for timesteps
-  for (i = 0; i < 2; i++) timesteps[i] = 0;
 
   /* release R resources */
   if (verbose) 
     Rprintf("\nNumber of time steps it = %d, it_ext = %d, it_tot = %d it_rej %d\n", 
       it, it_ext, it_tot, it_rej);
   /* release R resources */
+  timesteps[0] = 0;
+  timesteps[1] = 0;
+  
   restore_N_Protected(old_N_Protect);
   return(R_yout);
 }
+ 
+
