@@ -892,7 +892,7 @@ C --- JACOBIAN IS FULL
          END IF
       ELSE
 C --- COMPUTE JACOBIAN MATRIX ANALYTICALLY
-         CALL JAC(N,X,Y,FJAC,LDJAC,RPAR,IPAR)
+         CALL JAC(N,X,Y,MLJAC,MUJAC,FJAC,LDJAC,RPAR,IPAR)
       END IF
       CALJAC=.TRUE.
       CALHES=.TRUE.
